# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DdosBgpInstanceArgs', 'DdosBgpInstance']

@pulumi.input_type
class DdosBgpInstanceArgs:
    def __init__(__self__, *,
                 bandwidth: pulumi.Input[int],
                 ip_count: pulumi.Input[int],
                 ip_type: pulumi.Input[str],
                 normal_bandwidth: pulumi.Input[int],
                 base_bandwidth: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DdosBgpInstance resource.
        :param pulumi.Input[int] bandwidth: Elastic defend bandwidth of the instance. This value must be larger than the base defend bandwidth. Valid values: 51,91,101,201,301. The unit is Gbps.
        :param pulumi.Input[int] ip_count: IP count of the instance. Valid values: 100.
        :param pulumi.Input[str] ip_type: IP version of the instance. Valid values: IPv4,IPv6.
        :param pulumi.Input[int] normal_bandwidth: Normal defend bandwidth of the instance. The unit is Gbps.
        :param pulumi.Input[int] base_bandwidth: Base defend bandwidth of the instance. Valid values: 20. The unit is Gbps. Default to `20`.
        :param pulumi.Input[str] name: Name of the instance. This name can have a string of 1 to 63 characters.
        :param pulumi.Input[int] period: The duration that you will buy Ddosbgp instance (in month). Valid values: [1~9], 12, 24, 36. Default to 12. At present, the provider does not support modify "period".
        :param pulumi.Input[str] type: Type of the instance. Valid values: `Enterprise`, `Professional`. Default to `Enterprise`
        """
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "ip_count", ip_count)
        pulumi.set(__self__, "ip_type", ip_type)
        pulumi.set(__self__, "normal_bandwidth", normal_bandwidth)
        if base_bandwidth is not None:
            pulumi.set(__self__, "base_bandwidth", base_bandwidth)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Input[int]:
        """
        Elastic defend bandwidth of the instance. This value must be larger than the base defend bandwidth. Valid values: 51,91,101,201,301. The unit is Gbps.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: pulumi.Input[int]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="ipCount")
    def ip_count(self) -> pulumi.Input[int]:
        """
        IP count of the instance. Valid values: 100.
        """
        return pulumi.get(self, "ip_count")

    @ip_count.setter
    def ip_count(self, value: pulumi.Input[int]):
        pulumi.set(self, "ip_count", value)

    @property
    @pulumi.getter(name="ipType")
    def ip_type(self) -> pulumi.Input[str]:
        """
        IP version of the instance. Valid values: IPv4,IPv6.
        """
        return pulumi.get(self, "ip_type")

    @ip_type.setter
    def ip_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "ip_type", value)

    @property
    @pulumi.getter(name="normalBandwidth")
    def normal_bandwidth(self) -> pulumi.Input[int]:
        """
        Normal defend bandwidth of the instance. The unit is Gbps.
        """
        return pulumi.get(self, "normal_bandwidth")

    @normal_bandwidth.setter
    def normal_bandwidth(self, value: pulumi.Input[int]):
        pulumi.set(self, "normal_bandwidth", value)

    @property
    @pulumi.getter(name="baseBandwidth")
    def base_bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        Base defend bandwidth of the instance. Valid values: 20. The unit is Gbps. Default to `20`.
        """
        return pulumi.get(self, "base_bandwidth")

    @base_bandwidth.setter
    def base_bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "base_bandwidth", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the instance. This name can have a string of 1 to 63 characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The duration that you will buy Ddosbgp instance (in month). Valid values: [1~9], 12, 24, 36. Default to 12. At present, the provider does not support modify "period".
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the instance. Valid values: `Enterprise`, `Professional`. Default to `Enterprise`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class _DdosBgpInstanceState:
    def __init__(__self__, *,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 base_bandwidth: Optional[pulumi.Input[int]] = None,
                 ip_count: Optional[pulumi.Input[int]] = None,
                 ip_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 normal_bandwidth: Optional[pulumi.Input[int]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DdosBgpInstance resources.
        :param pulumi.Input[int] bandwidth: Elastic defend bandwidth of the instance. This value must be larger than the base defend bandwidth. Valid values: 51,91,101,201,301. The unit is Gbps.
        :param pulumi.Input[int] base_bandwidth: Base defend bandwidth of the instance. Valid values: 20. The unit is Gbps. Default to `20`.
        :param pulumi.Input[int] ip_count: IP count of the instance. Valid values: 100.
        :param pulumi.Input[str] ip_type: IP version of the instance. Valid values: IPv4,IPv6.
        :param pulumi.Input[str] name: Name of the instance. This name can have a string of 1 to 63 characters.
        :param pulumi.Input[int] normal_bandwidth: Normal defend bandwidth of the instance. The unit is Gbps.
        :param pulumi.Input[int] period: The duration that you will buy Ddosbgp instance (in month). Valid values: [1~9], 12, 24, 36. Default to 12. At present, the provider does not support modify "period".
        :param pulumi.Input[str] type: Type of the instance. Valid values: `Enterprise`, `Professional`. Default to `Enterprise`
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if base_bandwidth is not None:
            pulumi.set(__self__, "base_bandwidth", base_bandwidth)
        if ip_count is not None:
            pulumi.set(__self__, "ip_count", ip_count)
        if ip_type is not None:
            pulumi.set(__self__, "ip_type", ip_type)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if normal_bandwidth is not None:
            pulumi.set(__self__, "normal_bandwidth", normal_bandwidth)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        Elastic defend bandwidth of the instance. This value must be larger than the base defend bandwidth. Valid values: 51,91,101,201,301. The unit is Gbps.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="baseBandwidth")
    def base_bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        Base defend bandwidth of the instance. Valid values: 20. The unit is Gbps. Default to `20`.
        """
        return pulumi.get(self, "base_bandwidth")

    @base_bandwidth.setter
    def base_bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "base_bandwidth", value)

    @property
    @pulumi.getter(name="ipCount")
    def ip_count(self) -> Optional[pulumi.Input[int]]:
        """
        IP count of the instance. Valid values: 100.
        """
        return pulumi.get(self, "ip_count")

    @ip_count.setter
    def ip_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ip_count", value)

    @property
    @pulumi.getter(name="ipType")
    def ip_type(self) -> Optional[pulumi.Input[str]]:
        """
        IP version of the instance. Valid values: IPv4,IPv6.
        """
        return pulumi.get(self, "ip_type")

    @ip_type.setter
    def ip_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ip_type", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the instance. This name can have a string of 1 to 63 characters.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="normalBandwidth")
    def normal_bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        Normal defend bandwidth of the instance. The unit is Gbps.
        """
        return pulumi.get(self, "normal_bandwidth")

    @normal_bandwidth.setter
    def normal_bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "normal_bandwidth", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        The duration that you will buy Ddosbgp instance (in month). Valid values: [1~9], 12, 24, 36. Default to 12. At present, the provider does not support modify "period".
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the instance. Valid values: `Enterprise`, `Professional`. Default to `Enterprise`
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


warnings.warn("""alicloud.dns.DdosBgpInstance has been deprecated in favor of alicloud.ddos.DdosBgpInstance""", DeprecationWarning)


class DdosBgpInstance(pulumi.CustomResource):
    warnings.warn("""alicloud.dns.DdosBgpInstance has been deprecated in favor of alicloud.ddos.DdosBgpInstance""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 base_bandwidth: Optional[pulumi.Input[int]] = None,
                 ip_count: Optional[pulumi.Input[int]] = None,
                 ip_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 normal_bandwidth: Optional[pulumi.Input[int]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Anti-DDoS Advanced instance resource. "Ddosbgp" is the short term of this product.

        > **NOTE:** The endpoint of bssopenapi used only support "business.aliyuncs.com" at present.

        > **NOTE:** Available since v1.183.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        instance = alicloud.ddos.DdosBgpInstance("instance",
            name=name,
            base_bandwidth=20,
            bandwidth=-1,
            ip_count=100,
            ip_type="IPv4",
            normal_bandwidth=100,
            type="Enterprise")
        ```

        ## Import

        Ddosbgp instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dns/ddosBgpInstance:DdosBgpInstance example ddosbgp-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: Elastic defend bandwidth of the instance. This value must be larger than the base defend bandwidth. Valid values: 51,91,101,201,301. The unit is Gbps.
        :param pulumi.Input[int] base_bandwidth: Base defend bandwidth of the instance. Valid values: 20. The unit is Gbps. Default to `20`.
        :param pulumi.Input[int] ip_count: IP count of the instance. Valid values: 100.
        :param pulumi.Input[str] ip_type: IP version of the instance. Valid values: IPv4,IPv6.
        :param pulumi.Input[str] name: Name of the instance. This name can have a string of 1 to 63 characters.
        :param pulumi.Input[int] normal_bandwidth: Normal defend bandwidth of the instance. The unit is Gbps.
        :param pulumi.Input[int] period: The duration that you will buy Ddosbgp instance (in month). Valid values: [1~9], 12, 24, 36. Default to 12. At present, the provider does not support modify "period".
        :param pulumi.Input[str] type: Type of the instance. Valid values: `Enterprise`, `Professional`. Default to `Enterprise`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DdosBgpInstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Anti-DDoS Advanced instance resource. "Ddosbgp" is the short term of this product.

        > **NOTE:** The endpoint of bssopenapi used only support "business.aliyuncs.com" at present.

        > **NOTE:** Available since v1.183.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        instance = alicloud.ddos.DdosBgpInstance("instance",
            name=name,
            base_bandwidth=20,
            bandwidth=-1,
            ip_count=100,
            ip_type="IPv4",
            normal_bandwidth=100,
            type="Enterprise")
        ```

        ## Import

        Ddosbgp instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dns/ddosBgpInstance:DdosBgpInstance example ddosbgp-abc123456
        ```

        :param str resource_name: The name of the resource.
        :param DdosBgpInstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DdosBgpInstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 base_bandwidth: Optional[pulumi.Input[int]] = None,
                 ip_count: Optional[pulumi.Input[int]] = None,
                 ip_type: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 normal_bandwidth: Optional[pulumi.Input[int]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        pulumi.log.warn("""DdosBgpInstance is deprecated: alicloud.dns.DdosBgpInstance has been deprecated in favor of alicloud.ddos.DdosBgpInstance""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DdosBgpInstanceArgs.__new__(DdosBgpInstanceArgs)

            if bandwidth is None and not opts.urn:
                raise TypeError("Missing required property 'bandwidth'")
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["base_bandwidth"] = base_bandwidth
            if ip_count is None and not opts.urn:
                raise TypeError("Missing required property 'ip_count'")
            __props__.__dict__["ip_count"] = ip_count
            if ip_type is None and not opts.urn:
                raise TypeError("Missing required property 'ip_type'")
            __props__.__dict__["ip_type"] = ip_type
            __props__.__dict__["name"] = name
            if normal_bandwidth is None and not opts.urn:
                raise TypeError("Missing required property 'normal_bandwidth'")
            __props__.__dict__["normal_bandwidth"] = normal_bandwidth
            __props__.__dict__["period"] = period
            __props__.__dict__["type"] = type
        super(DdosBgpInstance, __self__).__init__(
            'alicloud:dns/ddosBgpInstance:DdosBgpInstance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth: Optional[pulumi.Input[int]] = None,
            base_bandwidth: Optional[pulumi.Input[int]] = None,
            ip_count: Optional[pulumi.Input[int]] = None,
            ip_type: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            normal_bandwidth: Optional[pulumi.Input[int]] = None,
            period: Optional[pulumi.Input[int]] = None,
            type: Optional[pulumi.Input[str]] = None) -> 'DdosBgpInstance':
        """
        Get an existing DdosBgpInstance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: Elastic defend bandwidth of the instance. This value must be larger than the base defend bandwidth. Valid values: 51,91,101,201,301. The unit is Gbps.
        :param pulumi.Input[int] base_bandwidth: Base defend bandwidth of the instance. Valid values: 20. The unit is Gbps. Default to `20`.
        :param pulumi.Input[int] ip_count: IP count of the instance. Valid values: 100.
        :param pulumi.Input[str] ip_type: IP version of the instance. Valid values: IPv4,IPv6.
        :param pulumi.Input[str] name: Name of the instance. This name can have a string of 1 to 63 characters.
        :param pulumi.Input[int] normal_bandwidth: Normal defend bandwidth of the instance. The unit is Gbps.
        :param pulumi.Input[int] period: The duration that you will buy Ddosbgp instance (in month). Valid values: [1~9], 12, 24, 36. Default to 12. At present, the provider does not support modify "period".
        :param pulumi.Input[str] type: Type of the instance. Valid values: `Enterprise`, `Professional`. Default to `Enterprise`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DdosBgpInstanceState.__new__(_DdosBgpInstanceState)

        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["base_bandwidth"] = base_bandwidth
        __props__.__dict__["ip_count"] = ip_count
        __props__.__dict__["ip_type"] = ip_type
        __props__.__dict__["name"] = name
        __props__.__dict__["normal_bandwidth"] = normal_bandwidth
        __props__.__dict__["period"] = period
        __props__.__dict__["type"] = type
        return DdosBgpInstance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[int]:
        """
        Elastic defend bandwidth of the instance. This value must be larger than the base defend bandwidth. Valid values: 51,91,101,201,301. The unit is Gbps.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="baseBandwidth")
    def base_bandwidth(self) -> pulumi.Output[Optional[int]]:
        """
        Base defend bandwidth of the instance. Valid values: 20. The unit is Gbps. Default to `20`.
        """
        return pulumi.get(self, "base_bandwidth")

    @property
    @pulumi.getter(name="ipCount")
    def ip_count(self) -> pulumi.Output[int]:
        """
        IP count of the instance. Valid values: 100.
        """
        return pulumi.get(self, "ip_count")

    @property
    @pulumi.getter(name="ipType")
    def ip_type(self) -> pulumi.Output[str]:
        """
        IP version of the instance. Valid values: IPv4,IPv6.
        """
        return pulumi.get(self, "ip_type")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of the instance. This name can have a string of 1 to 63 characters.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="normalBandwidth")
    def normal_bandwidth(self) -> pulumi.Output[int]:
        """
        Normal defend bandwidth of the instance. The unit is Gbps.
        """
        return pulumi.get(self, "normal_bandwidth")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[int]]:
        """
        The duration that you will buy Ddosbgp instance (in month). Valid values: [1~9], 12, 24, 36. Default to 12. At present, the provider does not support modify "period".
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[str]]:
        """
        Type of the instance. Valid values: `Enterprise`, `Professional`. Default to `Enterprise`
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstancesResult',
    'AwaitableGetInstancesResult',
    'get_instances',
    'get_instances_output',
]

@pulumi.output_type
class GetInstancesResult:
    """
    A collection of values returned by getInstances.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, instances=None, name_regex=None, names=None, output_file=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if instances and not isinstance(instances, list):
            raise TypeError("Expected argument 'instances' to be a list")
        pulumi.set(__self__, "instances", instances)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of instance IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def instances(self) -> Sequence['outputs.GetInstancesInstanceResult']:
        """
        A list of instances. Each element contains the following attributes:
        """
        return pulumi.get(self, "instances")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of instance names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetInstancesResult(GetInstancesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstancesResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            instances=self.instances,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file)


def get_instances(enable_details: Optional[bool] = None,
                  ids: Optional[Sequence[str]] = None,
                  name_regex: Optional[str] = None,
                  output_file: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstancesResult:
    """
    This data source provides a list of ALIKAFKA Instances in an Alibaba Cloud account according to the specified filters.

    > **NOTE:** Available in 1.59.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    instance_name = config.get("instanceName")
    if instance_name is None:
        instance_name = "alikafkaInstanceName"
    default = alicloud.get_zones(available_resource_creation="VSwitch")
    default_network = alicloud.vpc.Network("default", cidr_block="172.16.0.0/12")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=default.zones[0].id)
    default_instance = alicloud.alikafka.Instance("default",
        name=instance_name,
        partition_num=50,
        disk_type=1,
        disk_size=500,
        deploy_type=4,
        io_max=20,
        vswitch_id=default_switch.id)
    instances_ds = alicloud.actiontrail.get_instances(name_regex="alikafkaInstanceName",
        output_file="instances.txt")
    pulumi.export("firstInstanceName", instances_ds.instances[0].name)
    ```


    :param Sequence[str] ids: A list of instance IDs to filter results.
    :param str name_regex: A regex string to filter results by the instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:actiontrail/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult).value

    return AwaitableGetInstancesResult(
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        instances=pulumi.get(__ret__, 'instances'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_instances_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                         ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                         name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                         output_file: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstancesResult]:
    """
    This data source provides a list of ALIKAFKA Instances in an Alibaba Cloud account according to the specified filters.

    > **NOTE:** Available in 1.59.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    config = pulumi.Config()
    instance_name = config.get("instanceName")
    if instance_name is None:
        instance_name = "alikafkaInstanceName"
    default = alicloud.get_zones(available_resource_creation="VSwitch")
    default_network = alicloud.vpc.Network("default", cidr_block="172.16.0.0/12")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=default.zones[0].id)
    default_instance = alicloud.alikafka.Instance("default",
        name=instance_name,
        partition_num=50,
        disk_type=1,
        disk_size=500,
        deploy_type=4,
        io_max=20,
        vswitch_id=default_switch.id)
    instances_ds = alicloud.actiontrail.get_instances(name_regex="alikafkaInstanceName",
        output_file="instances.txt")
    pulumi.export("firstInstanceName", instances_ds.instances[0].name)
    ```


    :param Sequence[str] ids: A list of instance IDs to filter results.
    :param str name_regex: A regex string to filter results by the instance name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:actiontrail/getInstances:getInstances', __args__, opts=opts, typ=GetInstancesResult)
    return __ret__.apply(lambda __response__: GetInstancesResult(
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        instances=pulumi.get(__response__, 'instances'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAclsAclResult',
    'GetSmartagFlowLogsLogResult',
]

@pulumi.output_type
class GetAclsAclResult(dict):
    def __init__(__self__, *,
                 id: str,
                 name: str):
        """
        :param str id: The ID of the ACL. For example "acl-xxx".
        :param str name: The name of the Acl.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the ACL. For example "acl-xxx".
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the Acl.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetSmartagFlowLogsLogResult(dict):
    def __init__(__self__, *,
                 active_aging: int,
                 description: str,
                 flow_log_id: str,
                 flow_log_name: str,
                 id: str,
                 inactive_aging: int,
                 logstore_name: str,
                 netflow_server_ip: str,
                 netflow_server_port: int,
                 netflow_version: str,
                 output_type: str,
                 project_name: str,
                 resource_group_id: str,
                 sls_region_id: str,
                 status: str,
                 total_sag_num: int):
        """
        :param int active_aging: The time interval at which log data of active connections is collected. Valid values: 60 to 6000. Default value: 300. Unit: second.
        :param str description: The description of the flow log.
        :param str flow_log_id: The ID of the flow log.
        :param str flow_log_name: The name of the flow log.
        :param str id: The ID of the Flow Log.
        :param int inactive_aging: The time interval at which log data of inactive connections is connected. Valid values: 10 to 600. Default value: 15. Unit: second.
        :param str logstore_name: The name of the Log Service Logstore.
        :param str netflow_server_ip: The IP address of the NetFlow collector where the flow log is stored.
        :param int netflow_server_port: The port of the NetFlow collector. Default value: 9995.
        :param str netflow_version: The NetFlow version. Default value: V9.
        :param str output_type: The location where the flow log is stored. Valid values:  sls: The flow log is stored in Log Service. netflow: The flow log is stored on a NetFlow collector. all: The flow log is stored both in Log Service and on a NetFlow collector.
        :param str project_name: The name of the Log Service project.
        :param str resource_group_id: The ID of the resource group.
        :param str sls_region_id: The ID of the region where Log Service is deployed.
        :param str status: The status of the flow log. Valid values:  `Active`: The flow log is enabled. `Inactive`: The flow log is disabled.
        :param int total_sag_num: The number of Smart Access gateway (SAG) instances with which the flow log is associated.
        """
        pulumi.set(__self__, "active_aging", active_aging)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "flow_log_id", flow_log_id)
        pulumi.set(__self__, "flow_log_name", flow_log_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "inactive_aging", inactive_aging)
        pulumi.set(__self__, "logstore_name", logstore_name)
        pulumi.set(__self__, "netflow_server_ip", netflow_server_ip)
        pulumi.set(__self__, "netflow_server_port", netflow_server_port)
        pulumi.set(__self__, "netflow_version", netflow_version)
        pulumi.set(__self__, "output_type", output_type)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        pulumi.set(__self__, "sls_region_id", sls_region_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "total_sag_num", total_sag_num)

    @property
    @pulumi.getter(name="activeAging")
    def active_aging(self) -> int:
        """
        The time interval at which log data of active connections is collected. Valid values: 60 to 6000. Default value: 300. Unit: second.
        """
        return pulumi.get(self, "active_aging")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The description of the flow log.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="flowLogId")
    def flow_log_id(self) -> str:
        """
        The ID of the flow log.
        """
        return pulumi.get(self, "flow_log_id")

    @property
    @pulumi.getter(name="flowLogName")
    def flow_log_name(self) -> str:
        """
        The name of the flow log.
        """
        return pulumi.get(self, "flow_log_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Flow Log.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="inactiveAging")
    def inactive_aging(self) -> int:
        """
        The time interval at which log data of inactive connections is connected. Valid values: 10 to 600. Default value: 15. Unit: second.
        """
        return pulumi.get(self, "inactive_aging")

    @property
    @pulumi.getter(name="logstoreName")
    def logstore_name(self) -> str:
        """
        The name of the Log Service Logstore.
        """
        return pulumi.get(self, "logstore_name")

    @property
    @pulumi.getter(name="netflowServerIp")
    def netflow_server_ip(self) -> str:
        """
        The IP address of the NetFlow collector where the flow log is stored.
        """
        return pulumi.get(self, "netflow_server_ip")

    @property
    @pulumi.getter(name="netflowServerPort")
    def netflow_server_port(self) -> int:
        """
        The port of the NetFlow collector. Default value: 9995.
        """
        return pulumi.get(self, "netflow_server_port")

    @property
    @pulumi.getter(name="netflowVersion")
    def netflow_version(self) -> str:
        """
        The NetFlow version. Default value: V9.
        """
        return pulumi.get(self, "netflow_version")

    @property
    @pulumi.getter(name="outputType")
    def output_type(self) -> str:
        """
        The location where the flow log is stored. Valid values:  sls: The flow log is stored in Log Service. netflow: The flow log is stored on a NetFlow collector. all: The flow log is stored both in Log Service and on a NetFlow collector.
        """
        return pulumi.get(self, "output_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> str:
        """
        The name of the Log Service project.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> str:
        """
        The ID of the resource group.
        """
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter(name="slsRegionId")
    def sls_region_id(self) -> str:
        """
        The ID of the region where Log Service is deployed.
        """
        return pulumi.get(self, "sls_region_id")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the flow log. Valid values:  `Active`: The flow log is enabled. `Inactive`: The flow log is disabled.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="totalSagNum")
    def total_sag_num(self) -> int:
        """
        The number of Smart Access gateway (SAG) instances with which the flow log is associated.
        """
        return pulumi.get(self, "total_sag_num")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetInstanceClassInfosResult',
    'AwaitableGetInstanceClassInfosResult',
    'get_instance_class_infos',
    'get_instance_class_infos_output',
]

@pulumi.output_type
class GetInstanceClassInfosResult:
    """
    A collection of values returned by getInstanceClassInfos.
    """
    def __init__(__self__, commodity_code=None, db_instance_id=None, id=None, ids=None, infos=None, order_type=None, output_file=None):
        if commodity_code and not isinstance(commodity_code, str):
            raise TypeError("Expected argument 'commodity_code' to be a str")
        pulumi.set(__self__, "commodity_code", commodity_code)
        if db_instance_id and not isinstance(db_instance_id, str):
            raise TypeError("Expected argument 'db_instance_id' to be a str")
        pulumi.set(__self__, "db_instance_id", db_instance_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if infos and not isinstance(infos, list):
            raise TypeError("Expected argument 'infos' to be a list")
        pulumi.set(__self__, "infos", infos)
        if order_type and not isinstance(order_type, str):
            raise TypeError("Expected argument 'order_type' to be a str")
        pulumi.set(__self__, "order_type", order_type)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)

    @property
    @pulumi.getter(name="commodityCode")
    def commodity_code(self) -> str:
        return pulumi.get(self, "commodity_code")

    @property
    @pulumi.getter(name="dbInstanceId")
    def db_instance_id(self) -> Optional[str]:
        return pulumi.get(self, "db_instance_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Rds instance class codes.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def infos(self) -> Optional[Sequence['outputs.GetInstanceClassInfosInfoResult']]:
        """
        A list of Rds available resource. Each element contains the following attributes:
        """
        return pulumi.get(self, "infos")

    @property
    @pulumi.getter(name="orderType")
    def order_type(self) -> str:
        return pulumi.get(self, "order_type")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")


class AwaitableGetInstanceClassInfosResult(GetInstanceClassInfosResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceClassInfosResult(
            commodity_code=self.commodity_code,
            db_instance_id=self.db_instance_id,
            id=self.id,
            ids=self.ids,
            infos=self.infos,
            order_type=self.order_type,
            output_file=self.output_file)


def get_instance_class_infos(commodity_code: Optional[str] = None,
                             db_instance_id: Optional[str] = None,
                             infos: Optional[Sequence[Union['GetInstanceClassInfosInfoArgs', 'GetInstanceClassInfosInfoArgsDict']]] = None,
                             order_type: Optional[str] = None,
                             output_file: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceClassInfosResult:
    """
    This data source operation to query the instance types that are available to specific instances of Alibaba Cloud.

    > **NOTE:** Available in v1.196.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    resources = alicloud.rds.get_instance_class_infos(commodity_code="bards",
        order_type="BUY",
        output_file="./classes.txt")
    pulumi.export("firstDbInstanceClass", resources.infos[0])
    ```


    :param str commodity_code: The commodity code of the instance. Valid values:
           * **bards**: The instance is a pay-as-you-go primary instance. This value is available on the China site (aliyun.com).
           * **rds**: The instance is a subscription primary instance. This value is available on the China site (aliyun.com).
           * **rords**: The instance is a pay-as-you-go read-only instance. This value is available on the China site (aliyun.com).
           * **rds_rordspre_public_cn**: The instance is a subscription read-only instance. This value is available on the China site (aliyun.com).
           * **bards_intl**: The instance is a pay-as-you-go primary instance. This value is available on the International site (alibabacloud.com).
           * **rds_intl**: The instance is a subscription primary instance. This value is available on the International site (alibabacloud.com).
           * **rords_intl**: The instance is a pay-as-you-go read-only instance. This value is available on the International site (alibabacloud.com).
           * **rds_rordspre_public_intl**: The instance is a subscription read-only instance. This value is available on the International site (alibabacloud.com).
    :param str db_instance_id: The ID of the primary instance.
    :param Sequence[Union['GetInstanceClassInfosInfoArgs', 'GetInstanceClassInfosInfoArgsDict']] infos: A list of Rds available resource. Each element contains the following attributes:
    :param str order_type: FThe type of order that you want to query. Valid values:
           * **BUY**: specifies the query orders that are used to purchase instances.
           * **UPGRADE**: specifies the query orders that are used to change the specifications of instances.
           * **RENEW**: specifies the query orders that are used to renew instances.
           * **CONVERT**: specifies the query orders that are used to change the billing methods of instances.
    :param str output_file: File name where to save data source results (after running `pulumi up`).
           
           > **NOTE**: If you use the CommodityCode parameter to query the instance types that are available to read-only instances, you must specify the DBInstanceId parameter.
    """
    __args__ = dict()
    __args__['commodityCode'] = commodity_code
    __args__['dbInstanceId'] = db_instance_id
    __args__['infos'] = infos
    __args__['orderType'] = order_type
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:rds/getInstanceClassInfos:getInstanceClassInfos', __args__, opts=opts, typ=GetInstanceClassInfosResult).value

    return AwaitableGetInstanceClassInfosResult(
        commodity_code=pulumi.get(__ret__, 'commodity_code'),
        db_instance_id=pulumi.get(__ret__, 'db_instance_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        infos=pulumi.get(__ret__, 'infos'),
        order_type=pulumi.get(__ret__, 'order_type'),
        output_file=pulumi.get(__ret__, 'output_file'))
def get_instance_class_infos_output(commodity_code: Optional[pulumi.Input[str]] = None,
                                    db_instance_id: Optional[pulumi.Input[Optional[str]]] = None,
                                    infos: Optional[pulumi.Input[Optional[Sequence[Union['GetInstanceClassInfosInfoArgs', 'GetInstanceClassInfosInfoArgsDict']]]]] = None,
                                    order_type: Optional[pulumi.Input[str]] = None,
                                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstanceClassInfosResult]:
    """
    This data source operation to query the instance types that are available to specific instances of Alibaba Cloud.

    > **NOTE:** Available in v1.196.0+

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    resources = alicloud.rds.get_instance_class_infos(commodity_code="bards",
        order_type="BUY",
        output_file="./classes.txt")
    pulumi.export("firstDbInstanceClass", resources.infos[0])
    ```


    :param str commodity_code: The commodity code of the instance. Valid values:
           * **bards**: The instance is a pay-as-you-go primary instance. This value is available on the China site (aliyun.com).
           * **rds**: The instance is a subscription primary instance. This value is available on the China site (aliyun.com).
           * **rords**: The instance is a pay-as-you-go read-only instance. This value is available on the China site (aliyun.com).
           * **rds_rordspre_public_cn**: The instance is a subscription read-only instance. This value is available on the China site (aliyun.com).
           * **bards_intl**: The instance is a pay-as-you-go primary instance. This value is available on the International site (alibabacloud.com).
           * **rds_intl**: The instance is a subscription primary instance. This value is available on the International site (alibabacloud.com).
           * **rords_intl**: The instance is a pay-as-you-go read-only instance. This value is available on the International site (alibabacloud.com).
           * **rds_rordspre_public_intl**: The instance is a subscription read-only instance. This value is available on the International site (alibabacloud.com).
    :param str db_instance_id: The ID of the primary instance.
    :param Sequence[Union['GetInstanceClassInfosInfoArgs', 'GetInstanceClassInfosInfoArgsDict']] infos: A list of Rds available resource. Each element contains the following attributes:
    :param str order_type: FThe type of order that you want to query. Valid values:
           * **BUY**: specifies the query orders that are used to purchase instances.
           * **UPGRADE**: specifies the query orders that are used to change the specifications of instances.
           * **RENEW**: specifies the query orders that are used to renew instances.
           * **CONVERT**: specifies the query orders that are used to change the billing methods of instances.
    :param str output_file: File name where to save data source results (after running `pulumi up`).
           
           > **NOTE**: If you use the CommodityCode parameter to query the instance types that are available to read-only instances, you must specify the DBInstanceId parameter.
    """
    __args__ = dict()
    __args__['commodityCode'] = commodity_code
    __args__['dbInstanceId'] = db_instance_id
    __args__['infos'] = infos
    __args__['orderType'] = order_type
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:rds/getInstanceClassInfos:getInstanceClassInfos', __args__, opts=opts, typ=GetInstanceClassInfosResult)
    return __ret__.apply(lambda __response__: GetInstanceClassInfosResult(
        commodity_code=pulumi.get(__response__, 'commodity_code'),
        db_instance_id=pulumi.get(__response__, 'db_instance_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        infos=pulumi.get(__response__, 'infos'),
        order_type=pulumi.get(__response__, 'order_type'),
        output_file=pulumi.get(__response__, 'output_file')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'AnycastEipAddressAttachmentPopLocation',
    'GetAnycastEipAddressesAddressResult',
    'GetAnycastEipAddressesAddressAnycastEipBindInfoListResult',
]

@pulumi.output_type
class AnycastEipAddressAttachmentPopLocation(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "popLocation":
            suggest = "pop_location"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AnycastEipAddressAttachmentPopLocation. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AnycastEipAddressAttachmentPopLocation.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AnycastEipAddressAttachmentPopLocation.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 pop_location: Optional[str] = None):
        """
        :param str pop_location: The access point information of the associated access area when the cloud resource instance is bound.If you are binding for the first time, this parameter does not need to be configured, and the system automatically associates all access areas.
        """
        if pop_location is not None:
            pulumi.set(__self__, "pop_location", pop_location)

    @property
    @pulumi.getter(name="popLocation")
    def pop_location(self) -> Optional[str]:
        """
        The access point information of the associated access area when the cloud resource instance is bound.If you are binding for the first time, this parameter does not need to be configured, and the system automatically associates all access areas.
        """
        return pulumi.get(self, "pop_location")


@pulumi.output_type
class GetAnycastEipAddressesAddressResult(dict):
    def __init__(__self__, *,
                 ali_uid: int,
                 anycast_eip_address_name: str,
                 anycast_eip_bind_info_lists: Sequence['outputs.GetAnycastEipAddressesAddressAnycastEipBindInfoListResult'],
                 anycast_id: str,
                 bandwidth: int,
                 bid: str,
                 business_status: str,
                 description: str,
                 id: str,
                 internet_charge_type: str,
                 ip_address: str,
                 payment_type: str,
                 service_location: str,
                 status: str):
        """
        :param int ali_uid: Anycast EIP instance account ID.
        :param str anycast_eip_address_name: Anycast EIP instance name.
        :param Sequence['GetAnycastEipAddressesAddressAnycastEipBindInfoListArgs'] anycast_eip_bind_info_lists: AnycastEip binding information.
        :param str anycast_id: Anycast EIP instance ID.
        :param int bandwidth: The peak bandwidth of the Anycast EIP instance, in Mbps.
        :param str bid: Anycast EIP instance account BID.
        :param str business_status: The business status of the Anycast EIP instance. -`Normal`: Normal state. -`FinancialLocked`: The status of arrears locked.
        :param str description: Anycast EIP instance description.
        :param str id: The ID of the Anycast Eip Address.
        :param str internet_charge_type: The billing method of Anycast EIP instance. `PayByBandwidth`: refers to the method of billing based on traffic.
        :param str ip_address: Anycast EIP instance IP address.
        :param str payment_type: The payment model of Anycast EIP instance. "PostPaid": Refers to the post-paid mode.
        :param str service_location: Anycast EIP instance access area. "international": Refers to areas outside of Mainland China.
        :param str status: IP status。- `Associating`, `Unassociating`, `Allocated`, `Associated`, `Modifying`, `Releasing`, `Released`.
        """
        pulumi.set(__self__, "ali_uid", ali_uid)
        pulumi.set(__self__, "anycast_eip_address_name", anycast_eip_address_name)
        pulumi.set(__self__, "anycast_eip_bind_info_lists", anycast_eip_bind_info_lists)
        pulumi.set(__self__, "anycast_id", anycast_id)
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "bid", bid)
        pulumi.set(__self__, "business_status", business_status)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "internet_charge_type", internet_charge_type)
        pulumi.set(__self__, "ip_address", ip_address)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "service_location", service_location)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="aliUid")
    def ali_uid(self) -> int:
        """
        Anycast EIP instance account ID.
        """
        return pulumi.get(self, "ali_uid")

    @property
    @pulumi.getter(name="anycastEipAddressName")
    def anycast_eip_address_name(self) -> str:
        """
        Anycast EIP instance name.
        """
        return pulumi.get(self, "anycast_eip_address_name")

    @property
    @pulumi.getter(name="anycastEipBindInfoLists")
    def anycast_eip_bind_info_lists(self) -> Sequence['outputs.GetAnycastEipAddressesAddressAnycastEipBindInfoListResult']:
        """
        AnycastEip binding information.
        """
        return pulumi.get(self, "anycast_eip_bind_info_lists")

    @property
    @pulumi.getter(name="anycastId")
    def anycast_id(self) -> str:
        """
        Anycast EIP instance ID.
        """
        return pulumi.get(self, "anycast_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> int:
        """
        The peak bandwidth of the Anycast EIP instance, in Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter
    def bid(self) -> str:
        """
        Anycast EIP instance account BID.
        """
        return pulumi.get(self, "bid")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> str:
        """
        The business status of the Anycast EIP instance. -`Normal`: Normal state. -`FinancialLocked`: The status of arrears locked.
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        Anycast EIP instance description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Anycast Eip Address.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="internetChargeType")
    def internet_charge_type(self) -> str:
        """
        The billing method of Anycast EIP instance. `PayByBandwidth`: refers to the method of billing based on traffic.
        """
        return pulumi.get(self, "internet_charge_type")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> str:
        """
        Anycast EIP instance IP address.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment model of Anycast EIP instance. "PostPaid": Refers to the post-paid mode.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="serviceLocation")
    def service_location(self) -> str:
        """
        Anycast EIP instance access area. "international": Refers to areas outside of Mainland China.
        """
        return pulumi.get(self, "service_location")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        IP status。- `Associating`, `Unassociating`, `Allocated`, `Associated`, `Modifying`, `Releasing`, `Released`.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetAnycastEipAddressesAddressAnycastEipBindInfoListResult(dict):
    def __init__(__self__, *,
                 bind_instance_id: str,
                 bind_instance_region_id: str,
                 bind_instance_type: str,
                 bind_time: str):
        """
        :param str bind_instance_id: The bound cloud resource instance ID.
        :param str bind_instance_region_id: The region ID of the bound cloud resource instance.
        :param str bind_instance_type: Bind the cloud resource instance type.
        :param str bind_time: Binding time.
        """
        pulumi.set(__self__, "bind_instance_id", bind_instance_id)
        pulumi.set(__self__, "bind_instance_region_id", bind_instance_region_id)
        pulumi.set(__self__, "bind_instance_type", bind_instance_type)
        pulumi.set(__self__, "bind_time", bind_time)

    @property
    @pulumi.getter(name="bindInstanceId")
    def bind_instance_id(self) -> str:
        """
        The bound cloud resource instance ID.
        """
        return pulumi.get(self, "bind_instance_id")

    @property
    @pulumi.getter(name="bindInstanceRegionId")
    def bind_instance_region_id(self) -> str:
        """
        The region ID of the bound cloud resource instance.
        """
        return pulumi.get(self, "bind_instance_region_id")

    @property
    @pulumi.getter(name="bindInstanceType")
    def bind_instance_type(self) -> str:
        """
        Bind the cloud resource instance type.
        """
        return pulumi.get(self, "bind_instance_type")

    @property
    @pulumi.getter(name="bindTime")
    def bind_time(self) -> str:
        """
        Binding time.
        """
        return pulumi.get(self, "bind_time")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BucketReplicationArgs', 'BucketReplication']

@pulumi.input_type
class BucketReplicationArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[str],
                 destination: pulumi.Input['BucketReplicationDestinationArgs'],
                 action: Optional[pulumi.Input[str]] = None,
                 encryption_configuration: Optional[pulumi.Input['BucketReplicationEncryptionConfigurationArgs']] = None,
                 historical_object_replication: Optional[pulumi.Input[str]] = None,
                 prefix_set: Optional[pulumi.Input['BucketReplicationPrefixSetArgs']] = None,
                 progress: Optional[pulumi.Input['BucketReplicationProgressArgs']] = None,
                 source_selection_criteria: Optional[pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs']] = None,
                 sync_role: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a BucketReplication resource.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input['BucketReplicationDestinationArgs'] destination: Specifies the destination for the rule. See `destination` below.
        :param pulumi.Input[str] action: The operations that can be synchronized to the destination bucket. You can set action to one or more of the following operation types. Valid values: `ALL`(contains PUT, DELETE, and ABORT), `PUT`, `DELETE` and `ABORT`. Defaults to `ALL`.
        :param pulumi.Input['BucketReplicationEncryptionConfigurationArgs'] encryption_configuration: Specifies the encryption configuration for the objects replicated to the destination bucket. See `encryption_configuration` below.
        :param pulumi.Input[str] historical_object_replication: Specifies whether to replicate historical data from the source bucket to the destination bucket before data replication is enabled. Can be `enabled` or `disabled`. Defaults to `enabled`.
        :param pulumi.Input['BucketReplicationPrefixSetArgs'] prefix_set: The prefixes used to specify the object to replicate. Only objects that match the prefix are replicated to the destination bucket. See `prefix_set` below.
        :param pulumi.Input['BucketReplicationProgressArgs'] progress: Specifies the progress for querying the progress of a data replication task of a bucket.
        :param pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs'] source_selection_criteria: Specifies other conditions used to filter the source objects to replicate. See `source_selection_criteria` below.
        :param pulumi.Input[str] sync_role: Specifies the role that you authorize OSS to use to replicate data. If SSE-KMS is specified to encrypt the objects replicated to the destination bucket, it must be specified.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "destination", destination)
        if action is not None:
            pulumi.set(__self__, "action", action)
        if encryption_configuration is not None:
            pulumi.set(__self__, "encryption_configuration", encryption_configuration)
        if historical_object_replication is not None:
            pulumi.set(__self__, "historical_object_replication", historical_object_replication)
        if prefix_set is not None:
            pulumi.set(__self__, "prefix_set", prefix_set)
        if progress is not None:
            pulumi.set(__self__, "progress", progress)
        if source_selection_criteria is not None:
            pulumi.set(__self__, "source_selection_criteria", source_selection_criteria)
        if sync_role is not None:
            pulumi.set(__self__, "sync_role", sync_role)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Input['BucketReplicationDestinationArgs']:
        """
        Specifies the destination for the rule. See `destination` below.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: pulumi.Input['BucketReplicationDestinationArgs']):
        pulumi.set(self, "destination", value)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[str]]:
        """
        The operations that can be synchronized to the destination bucket. You can set action to one or more of the following operation types. Valid values: `ALL`(contains PUT, DELETE, and ABORT), `PUT`, `DELETE` and `ABORT`. Defaults to `ALL`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="encryptionConfiguration")
    def encryption_configuration(self) -> Optional[pulumi.Input['BucketReplicationEncryptionConfigurationArgs']]:
        """
        Specifies the encryption configuration for the objects replicated to the destination bucket. See `encryption_configuration` below.
        """
        return pulumi.get(self, "encryption_configuration")

    @encryption_configuration.setter
    def encryption_configuration(self, value: Optional[pulumi.Input['BucketReplicationEncryptionConfigurationArgs']]):
        pulumi.set(self, "encryption_configuration", value)

    @property
    @pulumi.getter(name="historicalObjectReplication")
    def historical_object_replication(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to replicate historical data from the source bucket to the destination bucket before data replication is enabled. Can be `enabled` or `disabled`. Defaults to `enabled`.
        """
        return pulumi.get(self, "historical_object_replication")

    @historical_object_replication.setter
    def historical_object_replication(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "historical_object_replication", value)

    @property
    @pulumi.getter(name="prefixSet")
    def prefix_set(self) -> Optional[pulumi.Input['BucketReplicationPrefixSetArgs']]:
        """
        The prefixes used to specify the object to replicate. Only objects that match the prefix are replicated to the destination bucket. See `prefix_set` below.
        """
        return pulumi.get(self, "prefix_set")

    @prefix_set.setter
    def prefix_set(self, value: Optional[pulumi.Input['BucketReplicationPrefixSetArgs']]):
        pulumi.set(self, "prefix_set", value)

    @property
    @pulumi.getter
    def progress(self) -> Optional[pulumi.Input['BucketReplicationProgressArgs']]:
        """
        Specifies the progress for querying the progress of a data replication task of a bucket.
        """
        return pulumi.get(self, "progress")

    @progress.setter
    def progress(self, value: Optional[pulumi.Input['BucketReplicationProgressArgs']]):
        pulumi.set(self, "progress", value)

    @property
    @pulumi.getter(name="sourceSelectionCriteria")
    def source_selection_criteria(self) -> Optional[pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs']]:
        """
        Specifies other conditions used to filter the source objects to replicate. See `source_selection_criteria` below.
        """
        return pulumi.get(self, "source_selection_criteria")

    @source_selection_criteria.setter
    def source_selection_criteria(self, value: Optional[pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs']]):
        pulumi.set(self, "source_selection_criteria", value)

    @property
    @pulumi.getter(name="syncRole")
    def sync_role(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the role that you authorize OSS to use to replicate data. If SSE-KMS is specified to encrypt the objects replicated to the destination bucket, it must be specified.
        """
        return pulumi.get(self, "sync_role")

    @sync_role.setter
    def sync_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sync_role", value)


@pulumi.input_type
class _BucketReplicationState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[str]] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 destination: Optional[pulumi.Input['BucketReplicationDestinationArgs']] = None,
                 encryption_configuration: Optional[pulumi.Input['BucketReplicationEncryptionConfigurationArgs']] = None,
                 historical_object_replication: Optional[pulumi.Input[str]] = None,
                 prefix_set: Optional[pulumi.Input['BucketReplicationPrefixSetArgs']] = None,
                 progress: Optional[pulumi.Input['BucketReplicationProgressArgs']] = None,
                 rule_id: Optional[pulumi.Input[str]] = None,
                 source_selection_criteria: Optional[pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs']] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 sync_role: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BucketReplication resources.
        :param pulumi.Input[str] action: The operations that can be synchronized to the destination bucket. You can set action to one or more of the following operation types. Valid values: `ALL`(contains PUT, DELETE, and ABORT), `PUT`, `DELETE` and `ABORT`. Defaults to `ALL`.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input['BucketReplicationDestinationArgs'] destination: Specifies the destination for the rule. See `destination` below.
        :param pulumi.Input['BucketReplicationEncryptionConfigurationArgs'] encryption_configuration: Specifies the encryption configuration for the objects replicated to the destination bucket. See `encryption_configuration` below.
        :param pulumi.Input[str] historical_object_replication: Specifies whether to replicate historical data from the source bucket to the destination bucket before data replication is enabled. Can be `enabled` or `disabled`. Defaults to `enabled`.
        :param pulumi.Input['BucketReplicationPrefixSetArgs'] prefix_set: The prefixes used to specify the object to replicate. Only objects that match the prefix are replicated to the destination bucket. See `prefix_set` below.
        :param pulumi.Input['BucketReplicationProgressArgs'] progress: Specifies the progress for querying the progress of a data replication task of a bucket.
        :param pulumi.Input[str] rule_id: The ID of the data replication rule.
        :param pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs'] source_selection_criteria: Specifies other conditions used to filter the source objects to replicate. See `source_selection_criteria` below.
        :param pulumi.Input[str] status: The status of the data replication task. Can be starting, doing and closing.
        :param pulumi.Input[str] sync_role: Specifies the role that you authorize OSS to use to replicate data. If SSE-KMS is specified to encrypt the objects replicated to the destination bucket, it must be specified.
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if destination is not None:
            pulumi.set(__self__, "destination", destination)
        if encryption_configuration is not None:
            pulumi.set(__self__, "encryption_configuration", encryption_configuration)
        if historical_object_replication is not None:
            pulumi.set(__self__, "historical_object_replication", historical_object_replication)
        if prefix_set is not None:
            pulumi.set(__self__, "prefix_set", prefix_set)
        if progress is not None:
            pulumi.set(__self__, "progress", progress)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)
        if source_selection_criteria is not None:
            pulumi.set(__self__, "source_selection_criteria", source_selection_criteria)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if sync_role is not None:
            pulumi.set(__self__, "sync_role", sync_role)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[str]]:
        """
        The operations that can be synchronized to the destination bucket. You can set action to one or more of the following operation types. Valid values: `ALL`(contains PUT, DELETE, and ABORT), `PUT`, `DELETE` and `ABORT`. Defaults to `ALL`.
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter
    def destination(self) -> Optional[pulumi.Input['BucketReplicationDestinationArgs']]:
        """
        Specifies the destination for the rule. See `destination` below.
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: Optional[pulumi.Input['BucketReplicationDestinationArgs']]):
        pulumi.set(self, "destination", value)

    @property
    @pulumi.getter(name="encryptionConfiguration")
    def encryption_configuration(self) -> Optional[pulumi.Input['BucketReplicationEncryptionConfigurationArgs']]:
        """
        Specifies the encryption configuration for the objects replicated to the destination bucket. See `encryption_configuration` below.
        """
        return pulumi.get(self, "encryption_configuration")

    @encryption_configuration.setter
    def encryption_configuration(self, value: Optional[pulumi.Input['BucketReplicationEncryptionConfigurationArgs']]):
        pulumi.set(self, "encryption_configuration", value)

    @property
    @pulumi.getter(name="historicalObjectReplication")
    def historical_object_replication(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies whether to replicate historical data from the source bucket to the destination bucket before data replication is enabled. Can be `enabled` or `disabled`. Defaults to `enabled`.
        """
        return pulumi.get(self, "historical_object_replication")

    @historical_object_replication.setter
    def historical_object_replication(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "historical_object_replication", value)

    @property
    @pulumi.getter(name="prefixSet")
    def prefix_set(self) -> Optional[pulumi.Input['BucketReplicationPrefixSetArgs']]:
        """
        The prefixes used to specify the object to replicate. Only objects that match the prefix are replicated to the destination bucket. See `prefix_set` below.
        """
        return pulumi.get(self, "prefix_set")

    @prefix_set.setter
    def prefix_set(self, value: Optional[pulumi.Input['BucketReplicationPrefixSetArgs']]):
        pulumi.set(self, "prefix_set", value)

    @property
    @pulumi.getter
    def progress(self) -> Optional[pulumi.Input['BucketReplicationProgressArgs']]:
        """
        Specifies the progress for querying the progress of a data replication task of a bucket.
        """
        return pulumi.get(self, "progress")

    @progress.setter
    def progress(self, value: Optional[pulumi.Input['BucketReplicationProgressArgs']]):
        pulumi.set(self, "progress", value)

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the data replication rule.
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rule_id", value)

    @property
    @pulumi.getter(name="sourceSelectionCriteria")
    def source_selection_criteria(self) -> Optional[pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs']]:
        """
        Specifies other conditions used to filter the source objects to replicate. See `source_selection_criteria` below.
        """
        return pulumi.get(self, "source_selection_criteria")

    @source_selection_criteria.setter
    def source_selection_criteria(self, value: Optional[pulumi.Input['BucketReplicationSourceSelectionCriteriaArgs']]):
        pulumi.set(self, "source_selection_criteria", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the data replication task. Can be starting, doing and closing.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="syncRole")
    def sync_role(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the role that you authorize OSS to use to replicate data. If SSE-KMS is specified to encrypt the objects replicated to the destination bucket, it must be specified.
        """
        return pulumi.get(self, "sync_role")

    @sync_role.setter
    def sync_role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sync_role", value)


class BucketReplication(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 destination: Optional[pulumi.Input[Union['BucketReplicationDestinationArgs', 'BucketReplicationDestinationArgsDict']]] = None,
                 encryption_configuration: Optional[pulumi.Input[Union['BucketReplicationEncryptionConfigurationArgs', 'BucketReplicationEncryptionConfigurationArgsDict']]] = None,
                 historical_object_replication: Optional[pulumi.Input[str]] = None,
                 prefix_set: Optional[pulumi.Input[Union['BucketReplicationPrefixSetArgs', 'BucketReplicationPrefixSetArgsDict']]] = None,
                 progress: Optional[pulumi.Input[Union['BucketReplicationProgressArgs', 'BucketReplicationProgressArgsDict']]] = None,
                 source_selection_criteria: Optional[pulumi.Input[Union['BucketReplicationSourceSelectionCriteriaArgs', 'BucketReplicationSourceSelectionCriteriaArgsDict']]] = None,
                 sync_role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides an independent replication configuration resource for OSS bucket.

        For information about OSS replication and how to use it, see [What is cross-region replication](https://www.alibabacloud.com/help/doc-detail/31864.html) and [What is same-region replication](https://www.alibabacloud.com/help/doc-detail/254865.html).

        > **NOTE:** Available since v1.161.0.

        ## Example Usage

        Set bucket replication configuration

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        bucket_src = alicloud.oss.Bucket("bucket_src", bucket=f"example-src-{default['result']}")
        bucket_dest = alicloud.oss.Bucket("bucket_dest", bucket=f"example-dest-{default['result']}")
        role = alicloud.ram.Role("role",
            name=f"example-role-{default['result']}",
            document=\"\"\"\\x09\\x09{
        \\x09\\x09  "Statement": [
        \\x09\\x09\\x09{
        \\x09\\x09\\x09  "Action": "sts:AssumeRole",
        \\x09\\x09\\x09  "Effect": "Allow",
        \\x09\\x09\\x09  "Principal": {
        \\x09\\x09\\x09\\x09"Service": [
        \\x09\\x09\\x09\\x09  "oss.aliyuncs.com"
        \\x09\\x09\\x09\\x09]
        \\x09\\x09\\x09  }
        \\x09\\x09\\x09}
        \\x09\\x09  ],
        \\x09\\x09  "Version": "1"
        \\x09\\x09}
        \"\"\",
            description="this is a test",
            force=True)
        policy = alicloud.ram.Policy("policy",
            policy_name=f"example-policy-{default['result']}",
            policy_document=\"\"\"\\x09\\x09{
        \\x09\\x09  "Statement": [
        \\x09\\x09\\x09{
        \\x09\\x09\\x09  "Action": [
        \\x09\\x09\\x09\\x09"*"
        \\x09\\x09\\x09  ],
        \\x09\\x09\\x09  "Effect": "Allow",
        \\x09\\x09\\x09  "Resource": [
        \\x09\\x09\\x09\\x09"*"
        \\x09\\x09\\x09  ]
        \\x09\\x09\\x09}
        \\x09\\x09  ],
        \\x09\\x09\\x09"Version": "1"
        \\x09\\x09}
        \"\"\",
            description="this is a policy test",
            force=True)
        attach = alicloud.ram.RolePolicyAttachment("attach",
            policy_name=policy.policy_name,
            policy_type=policy.type,
            role_name=role.name)
        key = alicloud.kms.Key("key",
            description="Hello KMS",
            pending_window_in_days=7,
            status="Enabled")
        cross_region_replication = alicloud.oss.BucketReplication("cross-region-replication",
            bucket=bucket_src.id,
            action="PUT,DELETE",
            historical_object_replication="enabled",
            prefix_set={
                "prefixes": [
                    "prefix1/",
                    "prefix2/",
                ],
            },
            destination={
                "bucket": bucket_dest.id,
                "location": bucket_dest.location,
            },
            sync_role=role.name,
            encryption_configuration={
                "replica_kms_key_id": key.id,
            },
            source_selection_criteria={
                "sse_kms_encrypted_objects": {
                    "status": "Enabled",
                },
            })
        ```

        ## Import

        ### Timeouts

        The `timeouts` block allows you to specify timeouts for certain actions:

        * `delete` - (Defaults to 30 mins) Used when delete a data replication rule (until the data replication task is cleared).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: The operations that can be synchronized to the destination bucket. You can set action to one or more of the following operation types. Valid values: `ALL`(contains PUT, DELETE, and ABORT), `PUT`, `DELETE` and `ABORT`. Defaults to `ALL`.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input[Union['BucketReplicationDestinationArgs', 'BucketReplicationDestinationArgsDict']] destination: Specifies the destination for the rule. See `destination` below.
        :param pulumi.Input[Union['BucketReplicationEncryptionConfigurationArgs', 'BucketReplicationEncryptionConfigurationArgsDict']] encryption_configuration: Specifies the encryption configuration for the objects replicated to the destination bucket. See `encryption_configuration` below.
        :param pulumi.Input[str] historical_object_replication: Specifies whether to replicate historical data from the source bucket to the destination bucket before data replication is enabled. Can be `enabled` or `disabled`. Defaults to `enabled`.
        :param pulumi.Input[Union['BucketReplicationPrefixSetArgs', 'BucketReplicationPrefixSetArgsDict']] prefix_set: The prefixes used to specify the object to replicate. Only objects that match the prefix are replicated to the destination bucket. See `prefix_set` below.
        :param pulumi.Input[Union['BucketReplicationProgressArgs', 'BucketReplicationProgressArgsDict']] progress: Specifies the progress for querying the progress of a data replication task of a bucket.
        :param pulumi.Input[Union['BucketReplicationSourceSelectionCriteriaArgs', 'BucketReplicationSourceSelectionCriteriaArgsDict']] source_selection_criteria: Specifies other conditions used to filter the source objects to replicate. See `source_selection_criteria` below.
        :param pulumi.Input[str] sync_role: Specifies the role that you authorize OSS to use to replicate data. If SSE-KMS is specified to encrypt the objects replicated to the destination bucket, it must be specified.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BucketReplicationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides an independent replication configuration resource for OSS bucket.

        For information about OSS replication and how to use it, see [What is cross-region replication](https://www.alibabacloud.com/help/doc-detail/31864.html) and [What is same-region replication](https://www.alibabacloud.com/help/doc-detail/254865.html).

        > **NOTE:** Available since v1.161.0.

        ## Example Usage

        Set bucket replication configuration

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        default = random.index.Integer("default",
            max=99999,
            min=10000)
        bucket_src = alicloud.oss.Bucket("bucket_src", bucket=f"example-src-{default['result']}")
        bucket_dest = alicloud.oss.Bucket("bucket_dest", bucket=f"example-dest-{default['result']}")
        role = alicloud.ram.Role("role",
            name=f"example-role-{default['result']}",
            document=\"\"\"\\x09\\x09{
        \\x09\\x09  "Statement": [
        \\x09\\x09\\x09{
        \\x09\\x09\\x09  "Action": "sts:AssumeRole",
        \\x09\\x09\\x09  "Effect": "Allow",
        \\x09\\x09\\x09  "Principal": {
        \\x09\\x09\\x09\\x09"Service": [
        \\x09\\x09\\x09\\x09  "oss.aliyuncs.com"
        \\x09\\x09\\x09\\x09]
        \\x09\\x09\\x09  }
        \\x09\\x09\\x09}
        \\x09\\x09  ],
        \\x09\\x09  "Version": "1"
        \\x09\\x09}
        \"\"\",
            description="this is a test",
            force=True)
        policy = alicloud.ram.Policy("policy",
            policy_name=f"example-policy-{default['result']}",
            policy_document=\"\"\"\\x09\\x09{
        \\x09\\x09  "Statement": [
        \\x09\\x09\\x09{
        \\x09\\x09\\x09  "Action": [
        \\x09\\x09\\x09\\x09"*"
        \\x09\\x09\\x09  ],
        \\x09\\x09\\x09  "Effect": "Allow",
        \\x09\\x09\\x09  "Resource": [
        \\x09\\x09\\x09\\x09"*"
        \\x09\\x09\\x09  ]
        \\x09\\x09\\x09}
        \\x09\\x09  ],
        \\x09\\x09\\x09"Version": "1"
        \\x09\\x09}
        \"\"\",
            description="this is a policy test",
            force=True)
        attach = alicloud.ram.RolePolicyAttachment("attach",
            policy_name=policy.policy_name,
            policy_type=policy.type,
            role_name=role.name)
        key = alicloud.kms.Key("key",
            description="Hello KMS",
            pending_window_in_days=7,
            status="Enabled")
        cross_region_replication = alicloud.oss.BucketReplication("cross-region-replication",
            bucket=bucket_src.id,
            action="PUT,DELETE",
            historical_object_replication="enabled",
            prefix_set={
                "prefixes": [
                    "prefix1/",
                    "prefix2/",
                ],
            },
            destination={
                "bucket": bucket_dest.id,
                "location": bucket_dest.location,
            },
            sync_role=role.name,
            encryption_configuration={
                "replica_kms_key_id": key.id,
            },
            source_selection_criteria={
                "sse_kms_encrypted_objects": {
                    "status": "Enabled",
                },
            })
        ```

        ## Import

        ### Timeouts

        The `timeouts` block allows you to specify timeouts for certain actions:

        * `delete` - (Defaults to 30 mins) Used when delete a data replication rule (until the data replication task is cleared).

        :param str resource_name: The name of the resource.
        :param BucketReplicationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BucketReplicationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[str]] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 destination: Optional[pulumi.Input[Union['BucketReplicationDestinationArgs', 'BucketReplicationDestinationArgsDict']]] = None,
                 encryption_configuration: Optional[pulumi.Input[Union['BucketReplicationEncryptionConfigurationArgs', 'BucketReplicationEncryptionConfigurationArgsDict']]] = None,
                 historical_object_replication: Optional[pulumi.Input[str]] = None,
                 prefix_set: Optional[pulumi.Input[Union['BucketReplicationPrefixSetArgs', 'BucketReplicationPrefixSetArgsDict']]] = None,
                 progress: Optional[pulumi.Input[Union['BucketReplicationProgressArgs', 'BucketReplicationProgressArgsDict']]] = None,
                 source_selection_criteria: Optional[pulumi.Input[Union['BucketReplicationSourceSelectionCriteriaArgs', 'BucketReplicationSourceSelectionCriteriaArgsDict']]] = None,
                 sync_role: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BucketReplicationArgs.__new__(BucketReplicationArgs)

            __props__.__dict__["action"] = action
            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            if destination is None and not opts.urn:
                raise TypeError("Missing required property 'destination'")
            __props__.__dict__["destination"] = destination
            __props__.__dict__["encryption_configuration"] = encryption_configuration
            __props__.__dict__["historical_object_replication"] = historical_object_replication
            __props__.__dict__["prefix_set"] = prefix_set
            __props__.__dict__["progress"] = progress
            __props__.__dict__["source_selection_criteria"] = source_selection_criteria
            __props__.__dict__["sync_role"] = sync_role
            __props__.__dict__["rule_id"] = None
            __props__.__dict__["status"] = None
        super(BucketReplication, __self__).__init__(
            'alicloud:oss/bucketReplication:BucketReplication',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[str]] = None,
            bucket: Optional[pulumi.Input[str]] = None,
            destination: Optional[pulumi.Input[Union['BucketReplicationDestinationArgs', 'BucketReplicationDestinationArgsDict']]] = None,
            encryption_configuration: Optional[pulumi.Input[Union['BucketReplicationEncryptionConfigurationArgs', 'BucketReplicationEncryptionConfigurationArgsDict']]] = None,
            historical_object_replication: Optional[pulumi.Input[str]] = None,
            prefix_set: Optional[pulumi.Input[Union['BucketReplicationPrefixSetArgs', 'BucketReplicationPrefixSetArgsDict']]] = None,
            progress: Optional[pulumi.Input[Union['BucketReplicationProgressArgs', 'BucketReplicationProgressArgsDict']]] = None,
            rule_id: Optional[pulumi.Input[str]] = None,
            source_selection_criteria: Optional[pulumi.Input[Union['BucketReplicationSourceSelectionCriteriaArgs', 'BucketReplicationSourceSelectionCriteriaArgsDict']]] = None,
            status: Optional[pulumi.Input[str]] = None,
            sync_role: Optional[pulumi.Input[str]] = None) -> 'BucketReplication':
        """
        Get an existing BucketReplication resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] action: The operations that can be synchronized to the destination bucket. You can set action to one or more of the following operation types. Valid values: `ALL`(contains PUT, DELETE, and ABORT), `PUT`, `DELETE` and `ABORT`. Defaults to `ALL`.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input[Union['BucketReplicationDestinationArgs', 'BucketReplicationDestinationArgsDict']] destination: Specifies the destination for the rule. See `destination` below.
        :param pulumi.Input[Union['BucketReplicationEncryptionConfigurationArgs', 'BucketReplicationEncryptionConfigurationArgsDict']] encryption_configuration: Specifies the encryption configuration for the objects replicated to the destination bucket. See `encryption_configuration` below.
        :param pulumi.Input[str] historical_object_replication: Specifies whether to replicate historical data from the source bucket to the destination bucket before data replication is enabled. Can be `enabled` or `disabled`. Defaults to `enabled`.
        :param pulumi.Input[Union['BucketReplicationPrefixSetArgs', 'BucketReplicationPrefixSetArgsDict']] prefix_set: The prefixes used to specify the object to replicate. Only objects that match the prefix are replicated to the destination bucket. See `prefix_set` below.
        :param pulumi.Input[Union['BucketReplicationProgressArgs', 'BucketReplicationProgressArgsDict']] progress: Specifies the progress for querying the progress of a data replication task of a bucket.
        :param pulumi.Input[str] rule_id: The ID of the data replication rule.
        :param pulumi.Input[Union['BucketReplicationSourceSelectionCriteriaArgs', 'BucketReplicationSourceSelectionCriteriaArgsDict']] source_selection_criteria: Specifies other conditions used to filter the source objects to replicate. See `source_selection_criteria` below.
        :param pulumi.Input[str] status: The status of the data replication task. Can be starting, doing and closing.
        :param pulumi.Input[str] sync_role: Specifies the role that you authorize OSS to use to replicate data. If SSE-KMS is specified to encrypt the objects replicated to the destination bucket, it must be specified.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BucketReplicationState.__new__(_BucketReplicationState)

        __props__.__dict__["action"] = action
        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["destination"] = destination
        __props__.__dict__["encryption_configuration"] = encryption_configuration
        __props__.__dict__["historical_object_replication"] = historical_object_replication
        __props__.__dict__["prefix_set"] = prefix_set
        __props__.__dict__["progress"] = progress
        __props__.__dict__["rule_id"] = rule_id
        __props__.__dict__["source_selection_criteria"] = source_selection_criteria
        __props__.__dict__["status"] = status
        __props__.__dict__["sync_role"] = sync_role
        return BucketReplication(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Output[Optional[str]]:
        """
        The operations that can be synchronized to the destination bucket. You can set action to one or more of the following operation types. Valid values: `ALL`(contains PUT, DELETE, and ABORT), `PUT`, `DELETE` and `ABORT`. Defaults to `ALL`.
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[str]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Output['outputs.BucketReplicationDestination']:
        """
        Specifies the destination for the rule. See `destination` below.
        """
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter(name="encryptionConfiguration")
    def encryption_configuration(self) -> pulumi.Output[Optional['outputs.BucketReplicationEncryptionConfiguration']]:
        """
        Specifies the encryption configuration for the objects replicated to the destination bucket. See `encryption_configuration` below.
        """
        return pulumi.get(self, "encryption_configuration")

    @property
    @pulumi.getter(name="historicalObjectReplication")
    def historical_object_replication(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies whether to replicate historical data from the source bucket to the destination bucket before data replication is enabled. Can be `enabled` or `disabled`. Defaults to `enabled`.
        """
        return pulumi.get(self, "historical_object_replication")

    @property
    @pulumi.getter(name="prefixSet")
    def prefix_set(self) -> pulumi.Output[Optional['outputs.BucketReplicationPrefixSet']]:
        """
        The prefixes used to specify the object to replicate. Only objects that match the prefix are replicated to the destination bucket. See `prefix_set` below.
        """
        return pulumi.get(self, "prefix_set")

    @property
    @pulumi.getter
    def progress(self) -> pulumi.Output['outputs.BucketReplicationProgress']:
        """
        Specifies the progress for querying the progress of a data replication task of a bucket.
        """
        return pulumi.get(self, "progress")

    @property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[str]:
        """
        The ID of the data replication rule.
        """
        return pulumi.get(self, "rule_id")

    @property
    @pulumi.getter(name="sourceSelectionCriteria")
    def source_selection_criteria(self) -> pulumi.Output[Optional['outputs.BucketReplicationSourceSelectionCriteria']]:
        """
        Specifies other conditions used to filter the source objects to replicate. See `source_selection_criteria` below.
        """
        return pulumi.get(self, "source_selection_criteria")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the data replication task. Can be starting, doing and closing.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="syncRole")
    def sync_role(self) -> pulumi.Output[Optional[str]]:
        """
        Specifies the role that you authorize OSS to use to replicate data. If SSE-KMS is specified to encrypt the objects replicated to the destination bucket, it must be specified.
        """
        return pulumi.get(self, "sync_role")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EcsSessionManagerStatusArgs', 'EcsSessionManagerStatus']

@pulumi.input_type
class EcsSessionManagerStatusArgs:
    def __init__(__self__, *,
                 session_manager_status_name: pulumi.Input[str],
                 status: pulumi.Input[str]):
        """
        The set of arguments for constructing a EcsSessionManagerStatus resource.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        pulumi.set(__self__, "session_manager_status_name", session_manager_status_name)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="sessionManagerStatusName")
    def session_manager_status_name(self) -> pulumi.Input[str]:
        """
        The name of the resource. Valid values: `sessionManagerStatus`.
        """
        return pulumi.get(self, "session_manager_status_name")

    @session_manager_status_name.setter
    def session_manager_status_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "session_manager_status_name", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[str]:
        """
        The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[str]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _EcsSessionManagerStatusState:
    def __init__(__self__, *,
                 session_manager_status_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EcsSessionManagerStatus resources.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        if session_manager_status_name is not None:
            pulumi.set(__self__, "session_manager_status_name", session_manager_status_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="sessionManagerStatusName")
    def session_manager_status_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the resource. Valid values: `sessionManagerStatus`.
        """
        return pulumi.get(self, "session_manager_status_name")

    @session_manager_status_name.setter
    def session_manager_status_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "session_manager_status_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class EcsSessionManagerStatus(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 session_manager_status_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a ECS Session Manager Status resource.

        For information about ECS Session Manager Status and how to use it, see [What is Session Manager Status](https://www.alibabacloud.com/help/zh/doc-detail/337915.html).

        > **NOTE:** Available in v1.148.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.EcsSessionManagerStatus("default",
            session_manager_status_name="sessionManagerStatus",
            status="Disabled")
        ```

        ## Import

        ECS Session Manager Status can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/ecsSessionManagerStatus:EcsSessionManagerStatus example <session_manager_status_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EcsSessionManagerStatusArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ECS Session Manager Status resource.

        For information about ECS Session Manager Status and how to use it, see [What is Session Manager Status](https://www.alibabacloud.com/help/zh/doc-detail/337915.html).

        > **NOTE:** Available in v1.148.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.ecs.EcsSessionManagerStatus("default",
            session_manager_status_name="sessionManagerStatus",
            status="Disabled")
        ```

        ## Import

        ECS Session Manager Status can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/ecsSessionManagerStatus:EcsSessionManagerStatus example <session_manager_status_name>
        ```

        :param str resource_name: The name of the resource.
        :param EcsSessionManagerStatusArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EcsSessionManagerStatusArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 session_manager_status_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EcsSessionManagerStatusArgs.__new__(EcsSessionManagerStatusArgs)

            if session_manager_status_name is None and not opts.urn:
                raise TypeError("Missing required property 'session_manager_status_name'")
            __props__.__dict__["session_manager_status_name"] = session_manager_status_name
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
        super(EcsSessionManagerStatus, __self__).__init__(
            'alicloud:ecs/ecsSessionManagerStatus:EcsSessionManagerStatus',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            session_manager_status_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'EcsSessionManagerStatus':
        """
        Get an existing EcsSessionManagerStatus resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] session_manager_status_name: The name of the resource. Valid values: `sessionManagerStatus`.
        :param pulumi.Input[str] status: The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EcsSessionManagerStatusState.__new__(_EcsSessionManagerStatusState)

        __props__.__dict__["session_manager_status_name"] = session_manager_status_name
        __props__.__dict__["status"] = status
        return EcsSessionManagerStatus(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="sessionManagerStatusName")
    def session_manager_status_name(self) -> pulumi.Output[str]:
        """
        The name of the resource. Valid values: `sessionManagerStatus`.
        """
        return pulumi.get(self, "session_manager_status_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource. Valid values: `Disabled`, `Enabled`.
        """
        return pulumi.get(self, "status")

